#################################
### Set the Working-Directory ###
#################################

### in R on a Mac
setwd("/Users/Ulrike/Documents/Veranstaltungen/2018 06 Workshop Data Analysis in R/Upload Package")


### in R on Windows
setwd("U:/Dokumente/Veranstaltungen/2018 06 Workshop Data Analysis in R")


#####################
### Read the Data ###
#####################
# i.e. "open" it in R

hesitations <- read.csv(file="Hesitation Placement in PPs.csv", head=T, sep=",", fileEncoding="utf8")

names(hesitations)

is.factor(hesitation$hes.position)
hesitation$hes.position <- as.factor(hesitation$hes.position)


#############################
### Install/Load Packages ###
#############################

install.packages("party")

library(party)



#####################
### Create a Tree ###
#####################

?ctree
?ctree_control

# a tree with a single predictor
tree1 <- ctree(hes.position ~ hes.type, data=hesitations)
plot(tree1, cex=.8)

tree2 <- ctree(hes.position ~ TPD_XP, data=hesitations)
plot(tree2, cex=.8)


# change the settings/prune the tree
tree3 <- ctree(hes.position ~ TPD_XP, controls=ctree_control(minbucket=100), data=hesitations)
plot(tree3, cex=.8)


# a tree with several predictors
tree4 <- ctree(hes.position ~ hes.type + freq_X + freq_P + freq_N + bifreq_XP + bifreq_PN + TPD_XP + TPD_PN + TPB_XP + TPB_PN + MI_XP + MI_PN + G_XP + G_PN + dPf_XP + dPf_PN + dPb_XP + dPb_PN, data=hesitations)
plot(tree4, cex=.8)


# a numeric dependent variable 
tree5 <- ctree(TPB_PN ~ hes.type + freq_X + freq_P + freq_N + bifreq_XP + bifreq_PN + TPD_XP + TPD_PN + TPB_XP +  MI_XP + MI_PN + G_XP + G_PN + dPf_XP + dPf_PN + dPb_XP + dPb_PN, data=hesitations)
plot(tree5, cex=.8)


# now we know why it is sometimes useful to prune the tree 
tree6 <- ctree(TPB_PN ~ hes.type + freq_X + freq_P + freq_N + bifreq_XP + bifreq_PN + TPD_XP + TPD_PN + TPB_XP +  MI_XP + MI_PN + G_XP + G_PN + dPf_XP + dPf_PN + dPb_XP + dPb_PN, controls=ctree_control(minbucket=100), data=hesitations)
plot(tree6, cex=.8)


# plot the tree in colour
colors()

plot(tree2, terminal_panel=node_barplot(tree2, col = "white", fill = c("red", "blue")))

plot(tree2, terminal_panel=node_barplot(tree2, col = "#6699CC", fill = c("#999999", "#9966CC")))

plot(tree2, terminal_panel=node_barplot(tree2, col = "white", fill = c("red", "blue")))


##########################################
### Assess the Performance of the Tree ###
### - Categorical Dependent Variable - ###
##########################################

table(predict(tree1), hesitations$hes.position)

table(predict(tree4), hesitations$hes.position)


nrow(hesitations)
table(hesitations$hes.position)
baseline <- c(515,405)

table(predict(tree1), hesitations$hes.position)
462+78
327+53
tree1_pred <- c(540,380)

chisq.test(tree1_pred, p = baseline, rescale.p = T)
residuals(chisq.test(tree1_pred, p = baseline, rescale.p = T))



table(predict(tree4), hesitations$hes.position)
350+321
165+84
tree4_pred <- c(671,249)

chisq.test(tree4_pred, p = baseline, rescale.p = T)
residuals(chisq.test(tree4_pred, p = baseline, rescale.p = T))



##########################################
### Assess the Performance of the Tree ###
###   - Numeric Dependent Variable -   ###
##########################################

summary(lm(hesitations$TPB_PN ~ predict(tree5)))
anova(lm(hesitations$TPB_PN ~ predict(tree5)))
plot(hesitations$TPB_PN ~ predict(tree5))

summary(lm(hesitations$TPB_PN ~ predict(tree6)))
plot(hesitations$TPB_PN ~ predict(tree6))







