#################################
### Set the Working-Directory ###
#################################

### in R on a Mac
setwd("/Users/Ulrike/Documents/Veranstaltungen/2018 06 Workshop Data Analysis in R/Upload Package")


### in R on Windows
setwd("U:/Dokumente/Veranstaltungen/2018 06 Workshop Data Analysis in R")


#####################
### Read the Data ###
#####################
# i.e. "open" it in R

hesitations <- read.csv(file="Hesitation Placement in PPs.csv", head=T, sep=",", fileEncoding="utf8")
hesitation$hes.position <- as.factor(hesitation$hes.position)

names(hesitations)


#############################
### Install/Load Packages ###
#############################

install.packages("party")

library(party)



#####################
### A Random Tree ###
#####################
# a single tree which exemplifies how a forest works

tree <- ctree(hes.position ~ hes.type + freq_X + freq_P + freq_N + bifreq_XP + bifreq_PN + TPD_XP + TPD_PN + TPB_XP + TPB_PN + MI_XP + MI_PN + G_XP + G_PN + dPf_XP + dPf_PN + dPb_XP + dPb_PN, controls=ctree_control(minbucket=100, mtry=3), data=sample(hesitations, size=750, replace=TRUE))
plot(tree, cex=.8)




####################
### Run a Forest ###
####################

# set the specifications
# ntree = number of trees per forest
# mtry = number of factors to select from for a split
data.controls <- cforest_unbiased(ntree=100, mtry=5)

forest1 <- cforest(hes.position ~ hes.type + freq_X + freq_P + freq_N + bifreq_XP + bifreq_PN + TPD_XP + TPD_PN + TPB_XP + TPB_PN + MI_XP + MI_PN + G_XP + G_PN + dPf_XP + dPf_PN + dPb_XP + dPb_PN, controls=data.controls, data=hesitations)


# if you want to, you can set the forest's seed
set.seed(1709)
data.controls <- cforest_unbiased(ntree=100, mtry=5)
forest1 <- cforest(hes.position ~ hes.type + freq_X + freq_P + freq_N + bifreq_XP + bifreq_PN + TPD_XP + TPD_PN + TPB_XP + TPB_PN + MI_XP + MI_PN + G_XP + G_PN + dPf_XP + dPf_PN + dPb_XP + dPb_PN, controls=data.controls, data=hesitations)






############################################
### Assess the Performance of the Forest ###
###      Non-Conservative                ###
############################################

table(predict(forest1), hesitations$hes.position)


nrow(hesitations)
table(hesitations$hes.position)
baseline <- c(515,405)

table(predict(forest1), hesitations$hes.position)
455+321
60+84
forest1_pred <- c(776,144)

chisq.test(forest1_pred, p = baseline, rescale.p = T)
residuals(chisq.test(forest1_pred, p = baseline, rescale.p = T))



############################################
### Assess the Performance of the Forest ###
###    Out-of-Bag (OOB) - Conservative   ###
############################################


table(predict(forest1, OOB=TRUE), hesitations$hes.position)
389+275
126+130
oob1_pred <- c(664,256)

chisq.test(oob1_pred, p = baseline, rescale.p = T)
residuals(chisq.test(oob1_pred, p = baseline, rescale.p = T))



################################################
### Assess the Performance of the Predictors ###
################################################

varimp1 <- varimp(forest1);varimp1

# save
write.csv(varimp1, "Variable Importance Forest1.csv")














